Welcome to the scikit-validate documentation!
===============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   quickstart
   commands
   reporting

   contributing
   authors
   history
   reference/modules

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
